@@ -1,10 +1,10 @@
 from collections import namedtuple
-from .settings import ZeroSettings, register_reload
+from .settings import ZeroSettings
 
 
 VersionInfo = namedtuple("VersionInfo", ("major", "minor", "patch"))
 
-VERSION = VersionInfo(0, 1, 5)
+VERSION = VersionInfo(0, 1, 6)
 
 __version__ = "{0.major}.{0.minor}.{0.patch}".format(VERSION)
-__all__ = [ZeroSettings, register_reload]
+__all__ = [ZeroSettings]
